#
# spec file for package nvmetcli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvmetcli
Version:        0.8
Release:        6.1
Summary:        Command line interface for the kernel NVMe nvmet
License:        Apache-2.0
Group:          System/Management
URL:            http://git.infradead.org/users/hch/nvmetcli.git
Source:         nvmetcli-v%{version}.tar.gz
Patch1:         nvmetcli-update-python-to-python3.patch
Patch2:         harden_nvmet.service.patch
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python3-pip
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-configshell-fb
Requires:       python3-kmodpy
Requires(post): systemd
Requires(postun): systemd
Requires(preun): systemd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package contains the command line interface to the NVMe over
Fabrics target in the Linux kernel. It allows configuring the NVMe
target interactively as well as saving / restoring the configuration
to / from a json file.

%prep
%autosetup -p1 -n nvmetcli-v%{version}

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
mkdir -p %{buildroot}%{_sysconfdir}/nvmet
mkdir -p %{buildroot}%{_prefix}/sbin
%if 0%{?suse_version} <= 1500
  install -m 755 nvmetcli %{buildroot}%{_sbindir}/nvmetcli
%else
  mv %{buildroot}%{_bindir}/nvmetcli %{buildroot}%{_sbindir}
%endif
mkdir -p %{buildroot}%{_prefix}/usr/sbin
ln -s /usr/sbin/service %{buildroot}/usr/sbin/rcnvmet
mkdir -p %{buildroot}%{_unitdir}
install -m 644 nvmet.service %{buildroot}%{_unitdir}/nvmet.service

%fdupes %{buildroot}/%{python3_sitelib}/nvmet

%post
%service_add_post nvmet.service

%pre
%service_add_pre nvmet.service

%preun
%service_del_preun nvmet.service

%postun
%service_del_postun nvmet.service

%files
%defattr(-,root,root,-)
%{python3_sitelib}
%dir %{_sysconfdir}/nvmet
%{_sbindir}/nvmetcli
/usr/sbin/rcnvmet
%{_unitdir}/nvmet.service
%doc COPYING README

%changelog
* Sun Mar 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Migrate from kmod to kmodpy -- both are supported, kmodpy is now
  packaged.
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools
* Mon Dec 11 2023 Daniel Wagner <daniel.wagner@suse.com>
- update old changelog entry so it mention that a patch has been removed
* Fri Dec  8 2023 Daniel Wagner <daniel.wagner@suse.com>
- add old changelog entry to changelog
* Tue Dec  5 2023 Daniel Wagner <daniel.wagner@suse.com>
- fix build on SLE15 code streams
* Fri Nov 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not define pythons: direclt use the python3 - relevant macros.
* Thu Nov  9 2023 Daniel Wagner <daniel.wagner@suse.com>
- Update to version v0.8: (jsc#PED-6252 jsc#PED-5728)
  * nvmetcli: set up the target only after the network is configured
  * nvmetcli: fixup ana groupid setting for namespaces
  * nvmetcli: add a tcp example json
  * nvmetcli: Correct xrange usage for py3
  * nvmetcli: Allow different devices for make test
  * nvmetcli: Report save name correctly
  * nvme.py: Make modprobe work for kmod lib too
  * nvme.py: Sync the containing directory
  * nvme.py: Explicit close is redundant
  * nvmetcli: Improve IOError handling on restore
  * nvmetcli: don't remove ANA Group 1 on clear
  * nvmetcli: ANA configuration support (bsc#1130981)
- remove 0001-nvmetcli-don-t-remove-ANA-Group-1-on-clear.patch
- remove nvmetcli-ANA-configuration-support.patch
- use autosetup instead listing all patches individual
- build package according PEP 517, 518. Thus don't call setup.py directly
- use fdupes to reduce package size
* Fri Nov 25 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_nvmet.service.patch
* Fri Mar 27 2020 hare@suse.de
- Update to version v0.7:
  * bump version to v0.7
  * nvmetcli: ANA configuration support
  * nvmetcli: simplify the enabled logic
  * nvmetcli: pep8 fixes
  * nvmetcli: support inline_data_size port parameter
  * Revert "nvmetcli: expose nvmet port status and state"
  * Support python3 dictionary access.
  * nvmetcli: expose nvmet port status and state
- Remove patch merged with upstream
  * nvmetcli-make-dict-access-python-version-independant.patch
- 'clear' command doesn't handle ANA groups correctly (bsc#1167644)
  adding patch
  - 0001-nvmetcli-don-t-remove-ANA-Group-1-on-clear.patch
* Fri Mar 29 2019 hare@suse.de
- Add ANA support (bsc#1130981)
  * nvmetcli-ANA-configuration-support.patch
* Mon Apr 16 2018 lduncan@suse.com
- Stop using singlespec, since we only need a
  python3 version of this package, and we do not
  want it named "python3-nvmetcli" (bsc#1082208).
  Also, use the "python-six" module to make
  dictionary iteration work for Python 2 and 3,
  adding patch:
  * nvmetcli-make-dict-access-python-version-independant.patch
* Fri Apr 13 2018 lduncan@suse.com
- Support python3 by using the python-six module,
  and convert dictionary access to use 'six' routines,
  so we can work on python 2 or python 3 (bsc#1082208)
* Sun Apr  8 2018 lduncan@suse.com
- Convert to Python3-only siglespec (bsc#1082208)
  * Update the SPEC file, using singlespec format, but
    telling the macros to ignore Python2
  * Tell the scripts to use Python3 instead of python,
    adding patch:
  - nvmetcli-update-python-to-python3.patch
* Tue Jan 23 2018 jthumshirn@suse.com
- Update to version v0.6: (FATE#322737)
  - 0001-nvmetcli-remove-status-method-for-the-uiportnode.patch
  * nvmetcli: remove status method for the UIPortNode
  * nvmetcli: expose ls to dump UI configuration
  * nvmetcli: decorate namespace, subsystem and port UI
  * nvmetcli: port decoration coloring only if its enabled
  * bump version to v0.6
* Fri Dec  1 2017 jthumshirn@suse.com
- Don't display bogus 'disabled' status for ports (bsc#1070533)
  + 0001-nvmetcli-remove-status-method-for-the-uiportnode.patch
* Fri Aug 11 2017 jthumshirn@suse.com
- Update to version v0.5: (FATE#322737)
  - 0001-nvmetcli-add-support-for-NS-UUIDs.patch
  * nvmetcli: add support for NS UUIDs
  * nvmetcli: allow setting of serial number number
  * nvmetcli: allow setting of the subsystem version
  * add a make clean pass to bump-ver.sh
  * bump version to v0.5
* Fri Jun 16 2017 jthumshirn@suse.com
- Add possibiliy to configure Namespace UUIDs (bsc#1038235)
  + 0001-nvmetcli-add-support-for-NS-UUIDs.patch
* Tue May 23 2017 jthumshirn@suse.com
- Change dependency from python-configshell to python-configshell-fb (bsc#1040212)
* Mon May  8 2017 jthumshirn@suse.com
- Update to version v0.4: (bsc#1034105)
  * add example configuration files
  * update .gitignore for the auto-generated manpage formats
  * add a bump-ver.sh script to automate cutting releases
  * bump version to v0.3
  * nvmetcli: fix Port and Host operations in shell
  * nvmetcli: fix Referral operation in shell
  * nvmetcli: Install nvmetcli in /usr/sbin with setup.py
  * nvmetcli: create json file's dir first if it doesn't exist
  * Add fc transport support to nvmetcli
  * bump version to v0.4
* Sat Feb 11 2017 jengelh@inai.de
- expand nvmet
* Wed Oct 12 2016 jthumshirn@suse.com
- Initial import for SUSE (FATE#321732)
